==> haskell-drbg-0.5.5-55-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-drbg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: DRBG
version: 0.5.5
id: DRBG-0.5.5-GPZhk1mH93EKbiYKYux9A4
key: DRBG-0.5.5-GPZhk1mH93EKbiYKYux9A4
license: BSD-3-Clause
maintainer: Thomas DuBuisson
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
synopsis: Deterministic random bit generator (aka RNG, PRNG) based
          HMACs, Hashes, and Ciphers.
description:
    Cryptographically secure RNGs
category: Cryptography
abi: 70c689174083917688df71476d342318
exposed: True
exposed-modules:
    Crypto.Random.DRBG Crypto.Random.DRBG.CTR Crypto.Random.DRBG.HMAC
    Crypto.Random.DRBG.Hash Crypto.Random.DRBG.Types
hidden-modules: Crypto.Random.DRBG.HashDF
import-dirs: /usr/lib/ghc-8.6.5/site-local/DRBG-0.5.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/DRBG-0.5.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/DRBG-0.5.5
hs-libraries: HSDRBG-0.5.5-GPZhk1mH93EKbiYKYux9A4
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    cereal-0.5.8.1-7AyRb7vLva5K85rZXh3kQh
    cipher-aes128-0.7.0.4-DBTDbOO07KA42MaPNe3Sf
    crypto-api-0.13.3-ALzE3By8BvHGVvnn2irh7V
    cryptohash-cryptoapi-0.1.4-ATv4Mt2c0fR8VQPhtDqwOZ
    entropy-0.4.1.4-23NMAjgKyCo3F1ZCvvDJOh mtl-2.2.2
    parallel-3.2.2.0-EGl5SOk48TWHAD161C93aQ
    prettyclass-1.0.0.0-TEwWRphxli3LO8yb54rr0
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
haddock-interfaces: /usr/share/doc/haskell-drbg/html/DRBG.haddock
haddock-html: /usr/share/doc/haskell-drbg/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-drbg-0.5.5-57-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-drbg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: DRBG
version: 0.5.5
id: DRBG-0.5.5-4svujtCFNm8JpIP6LLyhT
key: DRBG-0.5.5-4svujtCFNm8JpIP6LLyhT
license: BSD-3-Clause
maintainer: Thomas DuBuisson
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
synopsis: Deterministic random bit generator (aka RNG, PRNG) based
          HMACs, Hashes, and Ciphers.
description:
    Cryptographically secure RNGs
category: Cryptography
abi: 7504b9e21692c105440cc0cd63d13a6b
exposed: True
exposed-modules:
    Crypto.Random.DRBG Crypto.Random.DRBG.CTR Crypto.Random.DRBG.HMAC
    Crypto.Random.DRBG.Hash Crypto.Random.DRBG.Types
hidden-modules: Crypto.Random.DRBG.HashDF
import-dirs: /usr/lib/ghc-8.6.5/site-local/DRBG-0.5.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/DRBG-0.5.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/DRBG-0.5.5
hs-libraries: HSDRBG-0.5.5-4svujtCFNm8JpIP6LLyhT
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    cereal-0.5.8.1-7AyRb7vLva5K85rZXh3kQh
    cipher-aes128-0.7.0.4-DBTDbOO07KA42MaPNe3Sf
    crypto-api-0.13.3-ALzE3By8BvHGVvnn2irh7V
    cryptohash-cryptoapi-0.1.4-ATv4Mt2c0fR8VQPhtDqwOZ
    entropy-0.4.1.4-23NMAjgKyCo3F1ZCvvDJOh mtl-2.2.2
    parallel-3.2.2.0-EGl5SOk48TWHAD161C93aQ
    prettyclass-1.0.0.0-TEwWRphxli3LO8yb54rr0
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
haddock-interfaces: /usr/share/doc/haskell-drbg/html/DRBG.haddock
haddock-html: /usr/share/doc/haskell-drbg/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
